# About

This is a universal CM interface to run and customize all MLPerf inference benchmarks.
It is composed from the [portable automation recipes (CM scripts)](https://access.cknowledge.org/playground/?action=scripts).

Check [this documentation](https://github.com/mlcommons/ck/tree/master/docs/mlperf/inference) 
and [CM GUI](https://access.cknowledge.org/playground/?action=howtorun&bench_uid=39877bb63fb54725) 
to learn how to run MLPerf benchmarks via CM.



# Authors

* [Grigori Fursin](https://cKnowledge.org/gfursin)
* [Arjun Suresh](https://www.linkedin.com/in/arjunsuresh)


# Acknowledgments

We thank [the community](../../../CONTRIBUTING.md) for their suggestions and contributions!

